@@ -1,12 +1,10 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback;
-# git description: v0.013-1-gbaf35cc
-$Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::VERSION = '0.014';
+package Dist::Zilla::Plugin::ModuleBuildTiny::Fallback; # git description: v0.014-1-gafa4273
 # ABSTRACT: Build a Build.PL that uses Module::Build::Tiny, falling back to Module::Build as needed
 # KEYWORDS: plugin installer Module::Build Build.PL toolchain legacy ancient backcompat
 # vim: set ts=8 sw=4 tw=78 et :
-
+$Dist::Zilla::Plugin::ModuleBuildTiny::Fallback::VERSION = '0.015';
 use Moose;
 use MooseX::Types;
 use MooseX::Types::Moose 'ArrayRef';
@@ -200,8 +198,6 @@ my @missing = grep {
 
 if (not @missing)
 {
-    print "Congratulations, your toolchain understands 'configure_requires'!\n\n";
-
 FALLBACK2
     . <<"FALLBACK3"
 $mbt_content}
@@ -344,7 +340,7 @@ Dist::Zilla::Plugin::ModuleBuildTiny::Fallback - Build a Build.PL that uses Modu
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
